#!/usr/bin/perl

use GD::Graph::lines;
use MIME::Lite;
use Encode 'decode';
use strict;

my $cp = "koi8-r";

# graph.pl
# (c) 2009 Alexandr A Alexeev, http://eax.me/


open FID, "../../path/to/stat.log" or die "Failed to open stat file\n";

my $line;
my @data;
my $max = 0;

while($line = <FID>) {
  my @arr = split /:/, $line;
  my %row;
  for my $curr (@arr) {
    my ($k, $v) = split /=/, $curr;
    $row{$k} = $v;
  }
  
  my ($m, $d) = $row{date} =~ /^\d{4}-(\d{2})-(\d{2})$/;

  push @{$data[0]}, "$d.$m";
  push @{$data[1]}, $row{rss};
  push @{$data[2]}, $row{email};
  push @{$data[3]}, $row{lj};
  push @{$data[4]}, $row{twitter};

  for my $k (qw /rss email lj twitter/) {
    $max = $row{$k} if $row{$k} > $max;
  }
}

close FID;

my $graph = GD::Graph::lines->new(1000, 600);

$graph->set(
  x_label           => decode($cp, ''),
  y_label           => decode($cp, '-'),
  title             => decode($cp, ' '),
  y_max_value       => $max,
) or die $graph->error;

$graph->set_legend('RSS', 'E-Mail', 'LJ', 'Twitter');

my $gd = $graph->plot(\@data) or die $graph->error;

open(IMG, '>file.png') or die $!;
binmode IMG;
print IMG $gd->png;
close IMG;

my $msg = MIME::Lite->new(
  To => 'webmaster@example.ru',
  Subject => 'Graph',
  Type => 'multipart/mixed');

$msg->attach( Type => "text/plain; charset=$cp",
              Data => "  .  ." );
 
$msg->attach( Type        => 'image/png',
              Path        => 'file.png',
              Filename    => 'file.png',
              Disposition => 'attachment' );
 
$msg->send();
